.. _review-replying:

====================
Replying to Comments
====================

All reviews (including comments on code and file attachments) are shown on the
review request page in individual review boxes. Discussion about a particular
review will take place solely within that review box.

To reply to a comment in a review, click the :guilabel:`Add comment` link
below the comment on the right-hand side of the box. You can type your comment
and then press :guilabel:`OK` to save, or :guilabel:`Cancel` to discard the
comment.

You can use rich text in your replies using the :term:`Markdown` language. See
:ref:`using-markdown` for more information.

Unpublished comments (as indicated by your name in green) will appear only to
you. To publish your replies, click :guilabel:`Publish` in the reply draft
banner at the top of that review box.

Depending on the server setup, replying to a review may send out an e-mail to
all people involved in that review. This is displayed as part of a threaded
discussion in the e-mail clients. Because of this, you must publish replies on
a per-review basis. It's like replying to separate e-mail threads in a mail
client.
